==> wolf-1.6.1-20160905.115616-3-sources.jar: cn/com/duiba/wolf/utils/NumberUtils.java <==
package cn.com.duiba.wolf.utils;

import org.apache.commons.lang.StringUtils;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.Locale;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Number工具类
 * @author wenqi.huang on 16/4/8.
 */
public class NumberUtils {

    /**
     * 把字符串转换为int,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static int parseInt(String str, int defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        int value;
        try {
            value = Integer.parseInt(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把字符串转换为float,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static float parseFloat(String str, float defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        float value;
        try {
            value = Float.parseFloat(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把字符串转换为long,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static long parseLong(String str, long defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        long value;
        try {
            value = Long.parseLong(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把字符串转换为double,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static double parseDouble(String str, double defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        double value;
        try {
            value = Double.parseDouble(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把两个Long相加返回结果,null视为0
     * @param val1
     * @param val2
     * @return
     */
    public static Long add(Long val1, Long val2) {
        Long tmpval1 = val1 != null ? val1 : 0;
        Long tmpval2 = val2 != null ? val2 : 0;
        return tmpval1.longValue() + tmpval2.longValue();
    }

    /**
     * 把两个Integer相加返回结果,null视为0
     * @param val1
     * @param val2
     * @return
     */
    public static Integer add(Integer val1, Integer val2) {
        Integer tmpval1 = val1 != null ? val1 : 0;
        Integer tmpval2 = val2 != null ? val2 : 0;
        return tmpval1.intValue() + tmpval2.intValue();
    }

    /**
     * 把两个Double相加返回结果,null视为0
     * @param val1
     * @param val2
     * @return
     */
    public static Double add(Double val1, Double val2) {
        Double tmpval1 = val1 != null ? val1 : 0D;
        Double tmpval2 = val2 != null ? val2 : 0D;
        return tmpval1.doubleValue() + tmpval2.doubleValue();
    }

    /**
     * 把double转换为字符串,保留小数点后几位。
     * @param f
     * @param fractionDigits 指定需要保留小数点后几位。
     * @return
     */
    public static String numberFormat(double f, int fractionDigits) {
        NumberFormat nf1 = NumberFormat.getInstance(Locale.CHINA);
        nf1.setMaximumFractionDigits(fractionDigits);
        nf1.setGroupingUsed(false);//指定不使用逗号分隔符（每隔三位）
        return nf1.format(f);
    }

    /**
     * 把float转换为字符串,保留小数点后几位。
     * @param n
     * @param fractionDigits 指定需要保留小数点后几位。
     * @return
     */
    public static String numberFormat(float n, int fractionDigits) {
        NumberFormat nf = NumberFormat.getInstance();
        nf.setGroupingUsed(false);//指定不使用逗号分隔符（每隔三位）
        nf.setMaximumFractionDigits(fractionDigits);
        return nf.format(n);
    }

    /**
     * 把double转换为百分比字符串,比如0.121314会转换为12.13%,最多保留小数点后两位
     * @param d
     * @return
     */
    public static String percentFormat(double d) {
        DecimalFormat nf = (DecimalFormat) NumberFormat.getPercentInstance();
        nf.applyPattern("##.##%");
        return nf.format(d);
    }

    /**
     * 判断某个字符串是否是数字（允许包含0或1个小数点）
     * @param str
     * @return
     */
    public static boolean isNumeric(String str){
        if(StringUtils.isBlank(str)){
            return false;
        }
        Pattern pattern = Pattern.compile("[0-9]*\\.?[0-9]+");
        Matcher isNum = pattern.matcher(str);
        if( !isNum.matches() ){
            return false;
        }
        return true;
    }

    public static void main(String[] args){
        System.out.println(NumberUtils.parseInt("12",0));
    }

}

==> wolf-2.2.45-sources.jar: cn/com/duiba/wolf/utils/NumberUtils.java <==
package cn.com.duiba.wolf.utils;

import org.apache.commons.codec.binary.Base32;
import org.apache.commons.lang.StringUtils;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.Arrays;
import java.util.Locale;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Number工具类
 * @author wenqi.huang on 16/4/8.
 */
public class NumberUtils {

    /**
     * 把字符串转换为int,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static int parseInt(String str, int defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        int value;
        try {
            value = Integer.parseInt(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把字符串转换为float,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static float parseFloat(String str, float defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        float value;
        try {
            value = Float.parseFloat(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把字符串转换为long,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static long parseLong(String str, long defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        long value;
        try {
            value = Long.parseLong(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把字符串转换为double,如转换失败,则返回指定的默认值
     * @param str
     * @param defaultValue
     * @return
     */
    public static double parseDouble(String str, double defaultValue) {
        if (StringUtils.isEmpty(str)) {
            return defaultValue;
        }
        double value;
        try {
            value = Double.parseDouble(str.trim());
        } catch (Exception e) {
            value = defaultValue;
        }
        return value;
    }

    /**
     * 把两个Long相加返回结果,null视为0
     * @param val1
     * @param val2
     * @return
     */
    public static Long add(Long val1, Long val2) {
        Long tmpval1 = val1 != null ? val1 : 0;
        Long tmpval2 = val2 != null ? val2 : 0;
        return tmpval1.longValue() + tmpval2.longValue();
    }

    /**
     * 把两个Integer相加返回结果,null视为0
     * @param val1
     * @param val2
     * @return
     */
    public static Integer add(Integer val1, Integer val2) {
        Integer tmpval1 = val1 != null ? val1 : 0;
        Integer tmpval2 = val2 != null ? val2 : 0;
        return tmpval1.intValue() + tmpval2.intValue();
    }

    /**
     * 把两个Double相加返回结果,null视为0
     * @param val1
     * @param val2
     * @return
     */
    public static Double add(Double val1, Double val2) {
        Double tmpval1 = val1 != null ? val1 : 0D;
        Double tmpval2 = val2 != null ? val2 : 0D;
        return tmpval1.doubleValue() + tmpval2.doubleValue();
    }

    /**
     * 把double转换为字符串,保留小数点后几位。
     * @param f
     * @param fractionDigits 指定需要保留小数点后几位。
     * @return
     */
    public static String numberFormat(double f, int fractionDigits) {
        NumberFormat nf1 = NumberFormat.getInstance(Locale.CHINA);
        nf1.setMaximumFractionDigits(fractionDigits);
        nf1.setGroupingUsed(false);//指定不使用逗号分隔符（每隔三位）
        return nf1.format(f);
    }

    /**
     * 把float转换为字符串,保留小数点后几位。
     * @param n
     * @param fractionDigits 指定需要保留小数点后几位。
     * @return
     */
    public static String numberFormat(float n, int fractionDigits) {
        NumberFormat nf = NumberFormat.getInstance();
        nf.setGroupingUsed(false);//指定不使用逗号分隔符（每隔三位）
        nf.setMaximumFractionDigits(fractionDigits);
        return nf.format(n);
    }

    /**
     * 把double转换为百分比字符串,比如0.121314会转换为12.13%,最多保留小数点后两位
     * @param d
     * @return
     */
    public static String percentFormat(double d) {
        DecimalFormat nf = (DecimalFormat) NumberFormat.getPercentInstance();
        nf.applyPattern("##.##%");
        return nf.format(d);
    }

    /**
     * 判断某个字符串是否是数字（允许包含0或1个小数点）
     * @param str
     * @return
     */
    public static boolean isNumeric(String str){
        if(StringUtils.isBlank(str)){
            return false;
        }
        Pattern pattern = Pattern.compile("[0-9]*\\.?[0-9]+");
        Matcher isNum = pattern.matcher(str);
        if( !isNum.matches() ){
            return false;
        }
        return true;
    }

    /**
     * 把数字编码成较短的Base32字符串
     * @param l 需要编码成Base32字符串的数字
     * @return
     */
    public static String encodeLong2ShortBase32String(long l) {
        Base32 b = new Base32();
        return b.encodeToString(longToBytes(l)).replaceAll("=", "");
    }

    /**
     * 把经过encodeLong2ShortBase32String编码的字符串反解成数字
     * @param s 经过encodeLong2ShortBase32String编码的字符串
     * @return
     */
    public static long decodeShortBase32String2Long(String s) {
        Base32 b = new Base32();
        byte[] bs = b.decode(s);
        if (bs.length < 8){//如果不足8个byte，前面全部用0补齐
            byte[] nbs = new byte[8];
            int j = 0;
            for (int i=8-bs.length;i<8;i++) {
                nbs[i] = bs[j++];
            }
            bs = nbs;
        }

        return bytesToLong(bs);
    }

    private static byte[] longToBytes(long l) {
        int start = 0;
        byte[] b = new byte[8];
        b[0] = (byte) (l >>> 56);
        if(b[0] == 0){
            start++;
        }
        b[1] = (byte) (l >>> 48);
        if(b[1] == 0 && start == 1){
            start++;
        }
        b[2] = (byte) (l >>> 40);
        if(b[2] == 0 && start == 2){
            start++;
        }
        b[3] = (byte) (l >>> 32);
        if(b[3] == 0 && start == 3){
            start++;
        }
        b[4] = (byte) (l >>> 24);
        if(b[4] == 0 && start == 4){
            start++;
        }
        b[5] = (byte) (l >>> 16);
        if(b[5] == 0 && start == 5){
            start++;
        }
        b[6] = (byte) (l >>> 8);
        b[7] = (byte) (l);
        if(start > 0) {
            return Arrays.copyOfRange(b, start, 8);
        }
        return b;
    }

    private static long bytesToLong(byte[] b) {
        return (Byte.toUnsignedLong(b[0]) << 56) | (Byte.toUnsignedLong(b[1]) << 48)
                | (Byte.toUnsignedLong(b[2]) << 40) | (Byte.toUnsignedLong(b[3]) << 32)
                | (Byte.toUnsignedLong(b[4]) << 24) | (Byte.toUnsignedLong(b[5]) << 16)
                | (Byte.toUnsignedLong(b[6]) << 8) | Byte.toUnsignedLong(b[7]);
    }

}
